@@ -1,22 +1,29 @@
 
 ORG_SLUGS = list({
+    "20xx-splat",
     "altaira",
+    "aquatic-cup-retired",
     "area-cup",
     "armorless-adventures",
     "asquidmin",
     "aygi-gaming",
+    "bad-ideas-only",
     "bear-industries",
+    "betas-events",
     "boilermaker-booyah",
     "boo-yah-bros",
     "callisto",
     "camos-clan",
     "casual-friday",
     "cca-collegiate-cephalopod-association",
+    "campink",
     "ci-studios",
     "circuit-down-under",
     "coop-wiiu-competitive",
+    "dapple-productions",
     "deca-tower",
     "deep-sea-solutions",
+    "double-trouble-org",
     "dual-ink",
     "dyn",
     "dynamic-ink-testing-chamber",
@@ -24,8 +31,10 @@ ORG_SLUGS = list({
     "extrafest",
     "fresh-start-cup",
     "gamesetmatch",
+    "golf-club",
     "good-guys-win",
     "headspace-horoscopes",
+    "hyper-nyges-tournaments",
     "inkling-performance-labs",
     "inkloning",
     "inkopolis-bay",
@@ -35,7 +44,13 @@ ORG_SLUGS = list({
     "küki-tournaments",
     "little-squid-league",
     "lsi",
+    "marine-splat",
+    "meta-squid-tournament",
+    "midnight-hours",
+    "midpoint",
     "midway-ink-tour",
+    "mulloway-institute-of-turfing",
+    "narval-carnaval",
     "nebula-splatoon-2",
     "notorious-network-community-league",
     "off-the-dial",
@@ -49,21 +64,27 @@ ORG_SLUGS = list({
     "sleepy-cafe",
     "smash-online-global",
     "snowpoke",
+    "spacific-splatoon",
+    "spawnpointtv",
     "splashdown-saturdays",
     "splatcol",
     "splatcom",
     "splatendo-competitive™",
+    "splatoon-2-tournamentios",
     "splatoon-amateur-circuit",
     "splatoon-amino-official",
     "splatoon-sea-level-up-tournament-organization",
     "splatoon2",
     "splatoontbds",
     "splatoonvod-tournaments",
+    "splatum",
     "squid-garden",
     "squid-junction",
     "squid-south",
     "squid-spawning-grounds",
     "squidboards-splatoon-2-community-events",
+    "squids-out-of-water",
+    "stargaze-series",
     "sue_splat",
     "summer-splat-series",
     "swift-second-saturdays",
@@ -72,6 +93,7 @@ ORG_SLUGS = list({
     "the-ink-squad",
     "the-owo-gang",
     "the-reef",
+    "the-salmon-series",
     "toadstournaments",
     "torchy-gaming",
     "torneo-star-oni",
@@ -80,8 +102,10 @@ ORG_SLUGS = list({
     "turf-be-told",
     "ultimate-splat-championship",
     "under-the-ink",
+    "universal-splatoon-league",
     "vroom-vroom-veemo",
     "woomy-games-inc",
+    "worst-ever-tournament",
     "xanadu-tournament-series",
     "xtreme-tourneys",
     "young-ink-association",
